Package: AddiVortes
Title: (Bayesian) Additive Voronoi Tessellations
Version: 0.4.8
Date: 2026-01-14
Authors@R: 
    c(person("Adam", "Stone", , "adam.stone2@durham.ac.uk",
             role = c("aut"),
             comment = c(ORCID = "0009-0004-0058-6117")),
      person("John Paul", "Gosling", , "john-paul.gosling@durham.ac.uk",
             role = c("aut", "cre"),
             comment = c(ORCID = "0000-0002-4072-3022")))
Description: Implements the Bayesian Additive Voronoi Tessellation 
    model for non-parametric regression and machine learning as introduced
    in Stone and Gosling (2025) <doi:10.1080/10618600.2024.2414104>.
    This package provides a flexible alternative to BART (Bayesian Additive 
    Regression Trees) using Voronoi tessellations instead of trees. Users can 
    fit Bayesian regression models, estimate posterior distributions, and 
    visualise the resulting tessellations. It is particularly useful for spatial
    data analysis, machine learning regression, complex function approximation 
    and Bayesian modeling where the underlying structure is unknown. The method 
    is well-suited to capturing spatial patterns and non-linear relationships.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 3.5.0)
Imports: parallel (>= 4.0.0), pbapply (>= 1.6)
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), xml2
Config/testthat/edition: 3
URL: https://johnpaulgosling.github.io/AddiVortes/
VignetteBuilder: knitr
BugReports: https://github.com/johnpaulgosling/AddiVortes/issues
NeedsCompilation: yes
Packaged: 2026-01-14 11:21:54 UTC; rwzr85
Author: Adam Stone [aut] (ORCID: <https://orcid.org/0009-0004-0058-6117>),
  John Paul Gosling [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4072-3022>)
Maintainer: John Paul Gosling <john-paul.gosling@durham.ac.uk>
Repository: CRAN
Date/Publication: 2026-01-14 12:10:01 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 09:49:57 UTC; unix
Archs: AddiVortes.so.dSYM
