# Generated by roxygen2: do not edit by hand

S3method(plot,AddiVortesFit)
S3method(predict,AddiVortesFit)
S3method(print,AddiVortesFit)
S3method(summary,AddiVortesFit)
export(AddiVortes)
export(new_AddiVortesFit)
importFrom(graphics,abline)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(graphics,title)
importFrom(parallel,detectCores)
importFrom(parallel,makeCluster)
importFrom(parallel,parLapply)
importFrom(parallel,stopCluster)
importFrom(pbapply,pblapply)
importFrom(stats,dbinom)
importFrom(stats,dpois)
importFrom(stats,fitted)
importFrom(stats,lm)
importFrom(stats,lowess)
importFrom(stats,optim)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
useDynLib(AddiVortes, .registration = TRUE)
