% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AddiVortesFit.R
\name{summary.AddiVortes}
\alias{summary.AddiVortes}
\title{Summary Method for AddiVortes}
\usage{
\method{summary}{AddiVortes}(object, ...)
}
\arguments{
\item{object}{An object of class \code{AddiVortes}, typically the result of a
call to \code{AddiVortes()}.}

\item{...}{Further arguments passed to or from other methods (currently
unused).}
}
\value{
The function is called for its side effect of printing detailed model
information and returns the input object \code{object} invisibly.
}
\description{
Provides a detailed summary of a fitted \code{AddiVortes} object, including
more comprehensive information than the print method.
}
